==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_oc_prv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=oc_prv
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'APONDRE UN DOCUMENT', # MODIF
	'bouton_ajouter_image' => 'APONDRE UN IMATGE', # MODIF

	// D
	'double_clic_inserer_doc' => 'Besclicatz per inserir aquela acorcha dins lo tèxt.',

	// E
	'entree_dimensions' => 'Dimensions:',
	'entree_titre_document' => 'Títol dau document:',
	'entree_titre_image' => 'Títol de l’imatge:',

	// I
	'image_tourner_180' => 'Rotacion 180°',
	'image_tourner_droite' => 'Rotacion 90° cap a drecha',
	'image_tourner_gauche' => 'Rotacion 90° cap a esquerra',
	'info_document' => 'Document ',
	'info_documents' => 'Documents',
	'info_inclusion_directe' => 'Inclusion dirècta:',
	'info_inclusion_vignette' => 'Inclusion de la vinheta:',
	'info_installer_tous_documents' => 'Installar totei lei documents ',
	'info_logo_max_taille' => 'Lei lògos an de far mens de @maxi@ (aquest fichier fa @actuel@).',
	'info_portfolio' => 'Pòrtfòlio',
	'info_referencer_doc_distant' => 'Referenciar un document dins l’Internet:',
	'info_telecharger' => 'Telecargar a partir de vòstre ordenador:',

	// T
	'texte_documents_joints' => 'Podètz autorizar que s’apondan de documents (fichiers burotics, imatges,
 multimèdia, etc.) ais articles e/o ai rubricas. Aquelei fichiers,
 pòdon puei èsser referenciats dins
 l’article, o aparéisser a despart.', # MODIF
	'texte_documents_joints_2' => 'Aqueu reglatge empacha pas d’inserir d’imatges directament dins leis articles.', # MODIF
	'titre_documents_joints' => 'Documents jonchs',
	'tout_dossier_upload' => 'Tot lo dorsier @upload@',

	// U
	'upload_fichier_zip' => 'Fichier ZIP',
	'upload_fichier_zip_texte' => 'Lo fichier que prepausatz d’installar es un fichier Zip.',
	'upload_fichier_zip_texte2' => 'Aqueu fichier pòt èsser:',
	'upload_limit' => 'Aqueu fichier es tròp gròs per lo servidor; la talha maxima autorizada en <i>upload</i> es de @max@.',
	'upload_zip_decompacter' => 'descomprimit e cada element que conten installat sus lo sit. Alora lei fichiers que seràn installats sus lo sit son:',
	'upload_zip_telquel' => 'installat tau coma es, coma archiu comprimit Zip;'
);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_oc_prv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=oc_prv
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'APONDRE UN DOCUMENT', # MODIF
	'bouton_ajouter_image' => 'APONDRE UN IMATGE', # MODIF

	// D
	'double_clic_inserer_doc' => 'Besclicatz per inserir aquela acorcha dins lo tèxt.',

	// E
	'entree_dimensions' => 'Dimensions:',
	'entree_titre_document' => 'Títol dau document:',
	'entree_titre_image' => 'Títol de l’imatge:',

	// I
	'image_tourner_180' => 'Rotacion 180°',
	'image_tourner_droite' => 'Rotacion 90° cap a drecha',
	'image_tourner_gauche' => 'Rotacion 90° cap a esquerra',
	'info_document' => 'Document ',
	'info_documents' => 'Documents',
	'info_inclusion_directe' => 'Inclusion dirècta:',
	'info_inclusion_vignette' => 'Inclusion de la vinheta:',
	'info_installer_tous_documents' => 'Installar totei lei documents ',
	'info_logo_max_taille' => 'Lei lògos an de far mens de @maxi@ (aquest fichier fa @actuel@).',
	'info_portfolio' => 'Pòrtfòlio',
	'info_referencer_doc_distant' => 'Referenciar un document dins l’Internet:',
	'info_telecharger' => 'Telecargar a partir de vòstre ordenador:',

	// T
	'texte_documents_joints' => 'Podètz autorizar que s’apondan de documents (fichiers burotics, imatges,
 multimèdia, etc.) ais articles e/o ai rubricas. Aquelei fichiers,
 pòdon puei èsser referenciats dins
 l’article, o aparéisser a despart.', # MODIF
	'texte_documents_joints_2' => 'Aqueu reglatge empacha pas d’inserir d’imatges directament dins leis articles.', # MODIF
	'titre_documents_joints' => 'Documents jonchs',
	'tout_dossier_upload' => 'Tot lo dorsier @upload@',

	// U
	'upload_fichier_zip' => 'Fichier ZIP',
	'upload_fichier_zip_texte' => 'Lo fichier que prepausatz d’installar es un fichier Zip.',
	'upload_fichier_zip_texte2' => 'Aqueu fichier pòt èsser:',
	'upload_limit' => 'Aqueu fichier es tròp gròs per lo servidor; la talha maxima autorizada en <i>upload</i> es de @max@.',
	'upload_zip_decompacter' => 'descomprimit e cada element que conten installat sus lo sit. Alora lei fichiers que seràn installats sus lo sit son:',
	'upload_zip_telquel' => 'installat tau coma es, coma archiu comprimit Zip;',
];
